## 0.2.3 (2026-01-27)

### Fix

- **override**: remove 3.11 compatibility

## 0.2.2 (2026-01-27)

### Feat

- **SimpleListRoot**: add `pop` method

## 0.2.1 (2026-01-20)

### Feat

- **SimpleDict**: add `__contains__` method to get "X in Y" capability

## 0.2.0 (2025-11-18)

## 0.2.0b3 (2025-07-24)

### Feat

- **models.py**: add `empty` methods to SimpleListRoot and SimpleDict
- **base_type**: add `base_type` property to SimpleRoot for accessing the Generic that was used
- **SimpleDict**: add as a public api/aliased at root

### Fix

- **typing**: better overall typing

## 0.2.0b2 (2025-07-24)

### Feat

- **models.py**: add `empty` methods to SimpleListRoot and SimpleDict
- **base_type**: add `base_type` property to SimpleRoot for accessing the Generic that was used
- **SimpleDict**: add as a public api/aliased at root

### Fix

- **typing**: better overall typing

## 0.2.0b1 (2025-03-26)

### Feat

- **SimpleDict**: new Generic RootModel

## 0.2.0b0 (2025-03-26)

### Feat

- **SimpleGenericRoot**: a rootmodel for dictionaries that provides most methods that the root dictionary would provide

## 0.1.1b6 (2025-07-02)

### Feat

- **SimpleDict**: add as a public api/aliased at root
- **SimpleDict**: new Generic RootModel

### Fix

- **typing**: better overall typing

## 0.1.1b5 (2025-02-19)

### Refactor

- **SimpleRoot**: add overloads to SimpleRoot.get to improve type hinting; better exception messages when len(get()) != 1

## 0.1.1b4 (2025-02-07)

### Fix

- **Operators**: add `EQUAL` and `IEQUAL` with deprecation warning to use `EXACT` and `IEXACT`, respectively

## 0.1.1b3 (2025-02-05)

## 0.1.1b2 (2025-02-04)

### Feat

- **SimpleRoot**: add simpler root model for greater flexibility
- **SimpleRoot**: add SimpleRoot model for greater flexibility

## 0.1.1b1 (2025-01-31)

### Fix

- **dependencies**: open up python and pydantic dependencies to be more compatible

## 0.1.1b0 (2025-01-31)
